@@ -19,6 +19,7 @@
 #include <QFileInfo>
 #include <QDir>
 #include <QMimeDatabase>
+#include <QTimer>
 
 #if KFKIO_FOUND
 #include <KIO/OpenUrlJob>
@@ -176,12 +177,20 @@ public:
 
     QUrl mLoadedPlayListUrl;
 
+    QTimer mDurationChangedTimer;
 };
 
 MediaPlayListProxyModel::MediaPlayListProxyModel(QObject *parent) : QAbstractProxyModel (parent),
     d(std::make_unique<MediaPlayListProxyModelPrivate>())
 {
     d->mRandomGenerator.seed(static_cast<unsigned int>(QTime::currentTime().msec()));
+
+    d->mDurationChangedTimer.setInterval(50);
+    d->mDurationChangedTimer.setSingleShot(true);
+    connect(&d->mDurationChangedTimer, &QTimer::timeout, this, [this]() {
+        Q_EMIT remainingTracksDurationChanged();
+        Q_EMIT totalTracksDurationChanged();
+    });
 }
 
 MediaPlayListProxyModel::~MediaPlayListProxyModel()
@@ -236,7 +245,7 @@ QModelIndex MediaPlayListProxyModel::mapToSource(const QModelIndex &proxyIndex)
 
 int MediaPlayListProxyModel::mapRowToSource(const int proxyRow) const
 {
-    if (d->mShuffleMode != MediaPlayListProxyModel::Shuffle::NoShuffle) {
+    if (d->mRandomMapping.size() && d->mShuffleMode != MediaPlayListProxyModel::Shuffle::NoShuffle) {
         return d->mRandomMapping.at(proxyRow);
     } else {
         return proxyRow;
@@ -642,6 +651,13 @@ void MediaPlayListProxyModel::sourceRowsInserted(const QModelIndex &parent, int
         endInsertRows();
     }
 
+    const auto url = index(mapRowFromSource(start), 0).data(MediaPlayList::ResourceRole).toUrl();
+    if (d->mTriggerPlay == ElisaUtils::TriggerPlay && url.isValid()) {
+        switchTo(mapRowFromSource(start));
+        d->mTriggerPlay = ElisaUtils::DoNotTriggerPlay;
+        Q_EMIT requestPlay();
+    }
+
     if (d->mCurrentTrack.isValid()) {
         d->mCurrentPlayListPosition = d->mCurrentTrack.row();
         determineAndNotifyPreviousAndNextTracks();
@@ -649,10 +665,9 @@ void MediaPlayListProxyModel::sourceRowsInserted(const QModelIndex &parent, int
         determineTracks();
     }
 
+    d->mDurationChangedTimer.start();
     Q_EMIT tracksCountChanged();
-    Q_EMIT totalTracksDurationChanged();
     Q_EMIT remainingTracksChanged();
-    Q_EMIT remainingTracksDurationChanged();
     Q_EMIT persistentStateChanged();
 }
 
@@ -712,10 +727,9 @@ void MediaPlayListProxyModel::sourceRowsRemoved(const QModelIndex &parent, int s
     if (!d->mNextTrack.isValid() || !d->mPreviousTrack.isValid()) {
         determineAndNotifyPreviousAndNextTracks();
     }
+    d->mDurationChangedTimer.start();
     Q_EMIT tracksCountChanged();
-    Q_EMIT totalTracksDurationChanged();
     Q_EMIT remainingTracksChanged();
-    Q_EMIT remainingTracksDurationChanged();
     Q_EMIT persistentStateChanged();
 }
 
@@ -753,14 +767,15 @@ void MediaPlayListProxyModel::sourceDataChanged(const QModelIndex &topLeft, cons
     auto startSourceRow = topLeft.row();
     auto endSourceRow = bottomRight.row();
     for (int i = startSourceRow; i <= endSourceRow; i++) {
-        Q_EMIT dataChanged(index(mapRowFromSource(i), 0), index(mapRowFromSource(i), 0), roles);
-        Q_EMIT remainingTracksDurationChanged();
-        Q_EMIT totalTracksDurationChanged();
-        if (i == d->mCurrentTrack.row()) {
+        const auto proxyRow = mapRowFromSource(i);
+
+        d->mDurationChangedTimer.start();
+        Q_EMIT dataChanged(index(proxyRow, 0), index(proxyRow, 0), roles);
+        if (proxyRow == d->mCurrentTrack.row()) {
             Q_EMIT currentTrackDataChanged();
-        } else if (i == d->mNextTrack.row()) {
+        } else if (proxyRow == d->mNextTrack.row()) {
             Q_EMIT nextTrackDataChanged();
-        } else if (i == d->mPreviousTrack.row()) {
+        } else if (proxyRow == d->mPreviousTrack.row()) {
             Q_EMIT previousTrackDataChanged();
         }
         determineTracks();
